@@ -6,8 +6,8 @@ with open(sys.argv[1]) as fin:
     with open('s.svg', 'w') as fout:
         fout.write(scourString(fin.read()))
 
-subprocess.check_call(['rsvg', sys.argv[1], 'orig.png'])
-subprocess.check_call(['rsvg', 's.svg', 'new.png'])
+subprocess.check_call(['rsvg-convert', '-o', 'orig.png', sys.argv[1]])
+subprocess.check_call(['rsvg-convert', '-o', 'new.png', 's.svg'])
 with open('orig.png', 'rb') as forig:
     with open('new.png', 'rb') as fnew:
         assert forig.read() == fnew.read(), 'original and reduced files differ'
